<template>
  <div id="myPieChart" :class="className" :style="{height:height,width:width}" />
</template>

<script>
import * as echarts from 'echarts'
export default {
  props: {
    datas: {
      type: Array,
      default: []
    },
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '240px'
    },
    save: {
      type: Boolean,
      default: true
    }
  },
  data() {
    return {
      chart: null
    }
  },
  watch: {
    datas(val, oldVal) {
      this.initChart()
    }
  },
  mounted() {
    // this.$nextTick(() => {
    //   this.initChart()
    // })
    this.initChart()
  },
  beforeDestroy() {
    if (!this.chart) {
      return
    }
    this.chart.dispose()
    this.chart = null
  },
  methods: {
    initChart() {
      const chartDom = document.getElementById('myPieChart')
      const myChart = echarts.init(chartDom)
      this.chart = myChart

      this.chart.setOption({
        title: {
          text: '城市优良天统计柱状图',
          show: false
        },
        tooltip: {
          trigger: 'item',
          backgroundColor: 'rgba(255,255,255,.8)', // 通过设置rgba调节背景颜色与透明度
          color: 'gray',
          borderWidth: '1',
          borderColor: '#d9d9d9',
          formatter: function(val) {
            const name = val.name.split(':')[0]
            const proportion = val.name.split(':')[1]
            return name + '<br/>' + '天数: ' + val.value + '天' + '<br/>' + '占比:' + proportion
          },
          textStyle: {
            color: '#808080'
          }
        },
        toolbox: {
          feature: {
            saveAsImage: { show: this.save }
          }
        },
        color: ['#00e400', '#ffff00', '#ff7e00', '#ff0000', '#99004c', '#7e0023'],
        series: [
          {
            name: '',
            type: 'pie',
            radius: '70%',
            center: ['55%', '50%'],
            data: this.datas,
            label: {
              'normal': {
                'show': true,
                'textStyle': {
                  'fontSize': 12,
                  'color': '#808080'
                }
              },
              'emphasis': {
                'show': true
              }
            },
            labelLine: {
              normal: {
                smooth: 0.2,
                length: 9,
                length2: 18
              }
            },
            emphasis: {
              itemStyle: {
                shadowBlur: 10,
                shadowOffsetX: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
              }
            }
          }
        ]
      }, true)
    }
  }
}
</script>
